@@ -208,7 +208,8 @@ GList *         fr_window_get_selection                (FrWindow    *window,
 						        gboolean     from_sidebar,
 						        char       **return_base_dir);
 GtkTreeModel *  fr_window_get_list_store               (FrWindow    *window);
-void            fr_window_find                         (FrWindow    *window);
+void            fr_window_find                         (FrWindow    *window,
+							gboolean     active);
 void            fr_window_select_all                   (FrWindow    *window);
 void            fr_window_unselect_all                 (FrWindow    *window);
 
@@ -262,8 +263,6 @@ void            fr_window_set_extract_default_dir      (FrWindow   *window,
 							GFile      *default_dir,
 						        gboolean    freeze);
 GFile *         fr_window_get_extract_default_dir      (FrWindow   *window);
-void            fr_window_set_toolbar_visibility       (FrWindow   *window,
-						        gboolean    value);
 void            fr_window_set_statusbar_visibility     (FrWindow   *window,
 						        gboolean    value);
 void            fr_window_set_folders_visibility       (FrWindow   *window,
